==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/sq.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depozita është përkohësisht jashtë pune",
    "Storage invalid" : "Depozitë e pavlefshme",
    "Unknown error" : "Gabim i panjohur",
    "All files" : "Krejt kartelat",
    "Saved" : "U ruajt",
    "There was an error saving" : "Pati një gabim ruajtjeje",
    "File could not be found" : "Kartela s’u gjet dot",
    "Home" : "Kreu",
    "Close" : "Mbylle",
    "Favorites" : "Të parapëlqyera",
    "Could not create folder \"{dir}\"" : "S’u krijua dot dosja \"{dir}\"",
    "Upload cancelled." : "Ngarkimi u anulua.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "S’arrihet të ngarkohet {filename}, ngaqë është drejtori ose ka 0 bajte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nuk ka hapësirë të mjaftueshme, po ngarkoni {size1}, por ka vetëm {size2} të lira",
    "Target folder \"{dir}\" does not exist any more" : "Dosja vendmbërritje \"{dir}\" s’ekziston më",
    "Not enough free space" : "Pa hapësirë të lirë të mjaftueshme",
    "Uploading..." : "Po ngarkohet...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} nga {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Ngarkimi i kartelës është në punë e sipër. Largimi nga faqja do të anulojë ngarkimin.",
    "Actions" : "Veprime",
    "Download" : "Shkarkoje",
    "Rename" : "Riemërtojeni",
    "Delete" : "Fshije",
    "Disconnect storage" : "Shkëpute depozitën",
    "Unshare" : "Hiqe ndarjen",
    "Could not load info for file \"{file}\"" : "S’u ngarkuan dot të dhëna ose kartelë \"{file}\"",
    "Files" : "Kartela",
    "Details" : "Hollësi",
    "Select" : "Përzgjidhe",
    "Pending" : "Në pritje",
    "Unable to determine date" : "S’arrihet të përcaktohet data",
    "Invalid path" : "Shteg i pavlefshëm",
    "This operation is forbidden" : "Ky veprim është i ndaluar",
    "This directory is unavailable, please check the logs or contact the administrator" : "Kjo drejtori nuk kapet, ju lutemi, kontrolloni regjistrat ose lidhuni me përgjegjësin",
    "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
    "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
    "{newName} already exists" : "{newName} ekziston tashmë",
    "Could not rename \"{fileName}\", it does not exist any more" : "S’u riemërtua dot \"{fileName}\", s’ekziston më",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Emri \"{targetName}\" është tashmë i përdorur te dosja \"{dir}\". Ju lutemi, zgjidhni një emër tjetër.",
    "Could not rename \"{fileName}\"" : "S’u riemërtua dot \"{fileName}\"",
    "Could not create file \"{file}\"" : "S’u krijua dot kartela \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "S’u krijua dot kartela \"{file}\" ngaqë ka një të tillë",
    "Could not create folder \"{dir}\" because it already exists" : "S’u krijua dot dosja \"{dir}\" ngaqë ka një të tillë",
    "Error deleting file \"{fileName}\"." : "Gabim në fshirjen e kartelës \"{fileName}\".",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më",
    "_%n folder_::_%n folders_" : ["%n dosje","%n dosje"],
    "_%n file_::_%n files_" : ["%n kartelë","%n kartela"],
    "{dirs} and {files}" : "{dirs} dhe {files}",
    "_including %n hidden_::_including %n hidden_" : ["përfshi %n të fshehur","përfshi %n të fshehura"],
    "You don’t have permission to upload or create files here" : "S’keni leje për të ngarkuar apo krijuar kartela këtu",
    "_Uploading %n file_::_Uploading %n files_" : ["Po ngarkohet %n kartelë","Po ngarkohen %n kartela"],
    "New" : "E re",
    "\"{name}\" is an invalid file name." : "\"{name}\" është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Depozita e {owner} është plot, kartelat s’mund të përditësohen ose njëkohësohen më!",
    "Your storage is full, files can not be updated or synced anymore!" : "Depozita juaj është plot, kartelat s’mund të përditësohen ose njëkohësohen më!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Depozita e {owner} është thuasje plot ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depozita juaj është thuajse plot ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ka përputhje me '{filter}'","ka përputhje me '{filter}'"],
    "Path" : "Shteg",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajte"],
    "Favorited" : "U kalua e parapëlqyer",
    "Favorite" : "E parapëlqyer",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Lidhje private:  Mund ta përdorin vetëm personat që kanë hyrje te kartela/dosja. Përdoreni si një lidhje të përhershme për veten ose për të drejtuar të tjerë për te kartela brenda ndarjesh",
    "Folder" : "Dosje",
    "New folder" : "Dosje e re",
    "{newname} already exists" : "Ka tashmë një {newname}",
    "Upload" : "Ngarkoje",
    "An error occurred while trying to update the tags" : "Ndodhi një gabim teksa provohej të përditësoheshin etiketat",
    "A new file or folder has been <strong>created</strong>" : "<strong>U krijua</strong> një kartelë ose dosje e re",
    "A file or folder has been <strong>changed</strong>" : "<strong>U ndryshua</strong> një kartelë ose dosje",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Kufizojini njoftimet mbi krijim dhe ndryshim kartelash vetëm për <strong>kartelat tuaja të parapëlqyera</strong> <em>(Vetëm te rrjedha)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>U fshi</strong> një kartelë ose dosje",
    "A file or folder has been <strong>restored</strong>" : "<strong>U rikthye</strong> një kartelë ose dosje",
    "You created %1$s" : "Krijuat %1$s",
    "%2$s created %1$s" : "%2$s krijoi %1$s",
    "%1$s was created in a public folder" : "%1$s u krijua në një dosje publike",
    "You changed %1$s" : "Ndryshuat %1$s",
    "%2$s changed %1$s" : "%2$s ndryshoi %1$s",
    "You deleted %1$s" : "Fshitë %1$s",
    "%2$s deleted %1$s" : "%2$s fshiu %1$s",
    "You restored %1$s" : "Rikthyet %1$s",
    "%2$s restored %1$s" : "%2$s riktheu %1$s",
    "Changed by %2$s" : "Ndryshuar nga %2$s",
    "Deleted by %2$s" : "Fshirë nga %2$s",
    "Restored by %2$s" : "Rikthyer nga %2$s",
    "Upload (max. %s)" : "Ngarkim (max. %s)",
    "File handling" : "Trajtim kartele",
    "Maximum upload size" : "Madhësi maksimale ngarkimi",
    "max. possible: " : "maks. i mundshëm: ",
    "Save" : "Ruaje",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Me PHP-FPM mund të duhen 5 minuta që ndryshimet të hyjnë në fuqi.",
    "Missing permissions to edit from here." : "Mungojnë lejet për përpunim që nga këtu.",
    "Settings" : "Rregullime",
    "Show hidden files" : "Shfaq kartela të fshehura",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Përdorni këtë adresë për <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">të hyrë te Kartelat tuaja përmes WebDAV-it</a>",
    "No files in here" : "S’ka kartela këtu",
    "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
    "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
    "Select all" : "Përzgjidhe krejt",
    "Upload too large" : "Ngarkim shumë i madh",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kartelat që po rrekeni të ngarkoni e tejkalojnë madhësinë maksimale për ngarkime kartelash në këtë shërbyes.",
    "No favorites" : "Pa të parapëlqyera",
    "Files and folders you mark as favorite will show up here" : "Këtu do të duken kartelat dhe dosjet që i shënoni si të parapëlqyera",
    "Text file" : "Kartelë tekst",
    "New text file.txt" : "Kartelë e re file.txt",
    "Target folder does not exist any more" : "Dosja e synuar nuk ekziston më",
    "Upload timeout for file \"{file}\"" : "Mbarim kohe ngarkimi për kartelën \"{file}\"",
    "Processing files..." : "Po përpunohen kartela…",
    "No entries in this folder match {filter}" : "Në këtë dosje s’ka zëra me përputhje me {filter} ",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Kufizojini njoftimet rreth krijimit dhe ndryshimeve vetëm për <strong>kartelat tuaja të parapëlqyera</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "S’keni leje të hyni të përdorni këtë kartelë/dosje - Ju lutemi, lidhuni me të zotin e saj që ta ndajë me ju.",
    "Error when assembling chunks, status code {status}" : "Gabim gjatë montimit të copave, kod gjendjeje {status}",
    "The file {file} is currently locked, please try again later" : "Kartela {file} hëpërhë është e kyçur, ju lutemi, riprovoni më vonë",
    "Lock status" : "Gjendje kyçjeje",
    "This resource is locked. Click to see more details." : "Ky burim është i kyçur. Klikoni për të parë më tepër hollësi.",
    "{owner} has locked this resource via {path}" : "{owner} e ka kyçur këtë burim përmes {path}",
    "Could not unlock, please contact the lock owner {owner}" : "S’u shkyç dot, ju lutemi, lidhuni me të zotin e kyçjes {owner}",
    "Unlock failed with status {status}" : "Shkyçja dështoi, me gjendjen {status}",
    "Locks" : "Kyçje",
    "Resource is not locked" : "Burimi s’është i kyçur",
    "Unknown user" : "Përdorues i panjohur"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/sq.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depozita është përkohësisht jashtë pune",
    "Storage invalid" : "Depozitë e pavlefshme",
    "Unknown error" : "Gabim i panjohur",
    "All files" : "Krejt kartelat",
    "File could not be found" : "Kartela s’u gjet dot",
    "Home" : "Kreu",
    "Close" : "Mbylle",
    "Favorites" : "Të parapëlqyera",
    "Upload timeout for file \"{file}\"" : "Mbarim kohe ngarkimi për kartelën \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "Gabim i panjohur \"{error}\" gjatë ngarkimit të kartelës \"{file}\"",
    "Could not create folder \"{dir}\"" : "S’u krijua dot dosja \"{dir}\"",
    "Upload cancelled." : "Ngarkimi u anulua.",
    "The file {file} already exists" : "Kartela {file} ekziston tashmë",
    "Processing files..." : "Po përpunohen kartela…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "S’arrihet të ngarkohet {filename}, ngaqë është drejtori ose ka 0 bajte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nuk ka hapësirë të mjaftueshme, po ngarkoni {size1}, por ka vetëm {size2} të lira",
    "Target folder \"{dir}\" does not exist any more" : "Dosja vendmbërritje \"{dir}\" s’ekziston më",
    "Target folder does not exist any more" : "Dosja e synuar nuk ekziston më",
    "The file {file} is currently locked, please try again later" : "Kartela {file} hëpërhë është e kyçur, ju lutemi, riprovoni më vonë",
    "Not enough free space" : "Pa hapësirë të lirë të mjaftueshme",
    "Uploading..." : "Po ngarkohet...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} nga {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "Gabim gjatë montimit të copave, kod gjendjeje {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Ngarkimi i kartelës është në punë e sipër. Largimi nga faqja do të anulojë ngarkimin.",
    "Actions" : "Veprime",
    "Download" : "Shkarkoje",
    "Rename" : "Riemërtojeni",
    "Delete" : "Fshije",
    "Disconnect storage" : "Shkëpute depozitën",
    "Unshare" : "Hiqi ndarjen me të tjerë",
    "Could not load info for file \"{file}\"" : "S’u ngarkuan dot të dhëna ose kartelë \"{file}\"",
    "Files" : "Kartela",
    "Details" : "Hollësi",
    "Select" : "Përzgjidhe",
    "Pending" : "Në pritje",
    "Unable to determine date" : "S’arrihet të përcaktohet data",
    "Invalid path" : "Shteg i pavlefshëm",
    "This operation is forbidden" : "Ky veprim është i ndaluar",
    "This directory is unavailable, please check the logs or contact the administrator" : "Kjo drejtori nuk kapet, ju lutemi, kontrolloni regjistrat ose lidhuni me përgjegjësin",
    "group" : "grup",
    "Remote share" : "Ndarje e largët",
    "via" : "përmes",
    "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
    "Could not move \"{file}\" because either the file or the target are locked." : "S’u lëviz dot \"{file}\", ngaqë ose kartela vetë, ose vendmbërritja është e kyçur.",
    "Could not move \"{file}\": {message}" : "S’u lëviz dot \"{file}\": {message}",
    "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
    "{newName} already exists" : "{newName} ekziston tashmë",
    "Could not rename \"{fileName}\", it does not exist any more" : "S’u riemërtua dot \"{fileName}\", s’ekziston më",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Emri \"{targetName}\" është tashmë i përdorur te dosja \"{dir}\". Ju lutemi, zgjidhni një emër tjetër.",
    "The file \"{fileName}\" is locked and can not be renamed." : "Kartela \"{fileName}\" është e kyçur dhe s’mund të riemërtohet.",
    "Could not rename \"{fileName}\"" : "S’u riemërtua dot \"{fileName}\"",
    "Could not create file \"{file}\"" : "S’u krijua dot kartela \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "S’u krijua dot kartela \"{file}\" ngaqë ka një të tillë",
    "Could not create folder \"{dir}\" because it already exists" : "S’u krijua dot dosja \"{dir}\" ngaqë ka një të tillë",
    "The file \"{fileName}\" is locked and cannot be deleted." : "Kartela \"{fileName}\" është e kyçur dhe s’mund të fshihet.",
    "Error deleting file \"{fileName}\"." : "Gabim në fshirjen e kartelës \"{fileName}\".",
    "No entries in this folder match {filter}" : "Në këtë dosje s’ka zëra me përputhje me {filter} ",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më",
    "_%n folder_::_%n folders_" : ["%n dosje","%n dosje"],
    "_%n file_::_%n files_" : ["%n kartelë","%n kartela"],
    "{dirs} and {files}" : "{dirs} dhe {files}",
    "_including %n hidden_::_including %n hidden_" : ["përfshi %n të fshehur","përfshi %n të fshehura"],
    "You don’t have permission to upload or create files here" : "S’keni leje për të ngarkuar apo krijuar kartela këtu",
    "_Uploading %n file_::_Uploading %n files_" : ["Po ngarkohet %n kartelë","Po ngarkohen %n kartela"],
    "New" : "E re",
    "Unknown user" : "Përdorues i panjohur",
    "Lock status" : "Gjendje kyçjeje",
    "This resource is locked. Click to see more details." : "Ky burim është i kyçur. Klikoni për të parë më tepër hollësi.",
    "\"{name}\" is an invalid file name." : "\"{name}\" është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "File name cannot contain \"/\"." : "Emri i kartelës s’mund të përmbajë \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" ka një lloj/zgjatim të ndaluar për kartelat.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Depozita e {owner} është plot, kartelat s’mund të përditësohen ose njëkohësohen më!",
    "Your storage is full, files can not be updated or synced anymore!" : "Depozita juaj është plot, kartelat s’mund të përditësohen ose njëkohësohen më!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Depozita e {owner} është thuasje plot ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depozita juaj është thuajse plot ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ka përputhje me '{filter}'","ka përputhje me '{filter}'"],
    "{owner} has locked this resource via {path}" : "{owner} e ka kyçur këtë burim përmes {path}",
    "Could not unlock, please contact the lock owner {owner}" : "S’u shkyç dot, ju lutemi, lidhuni me të zotin e kyçjes {owner}",
    "Unlock failed with status {status}" : "Shkyçja dështoi, me gjendjen {status}",
    "Locks" : "Kyçje",
    "Resource is not locked" : "Burimi s’është i kyçur",
    "Path" : "Shteg",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajte"],
    "Favorited" : "U kalua e parapëlqyer",
    "Favorite" : "E parapëlqyer",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Lidhje private:  Mund ta përdorin vetëm personat që kanë hyrje te kartela/dosja. Përdoreni si një lidhje të përhershme për veten ose për të drejtuar të tjerë për te kartela brenda ndarjesh",
    "Folder" : "Dosje",
    "New folder" : "Dosje e re",
    "{newname} already exists" : "Ka tashmë një {newname}",
    "Upload" : "Ngarkoje",
    "An error occurred while trying to update the tags" : "Ndodhi një gabim teksa provohej të përditësoheshin etiketat",
    "A new file or folder has been <strong>created</strong>" : "<strong>U krijua</strong> një kartelë ose dosje e re",
    "A file or folder has been <strong>changed</strong>" : "<strong>U ndryshua</strong> një kartelë ose dosje",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Kufizojini njoftimet mbi krijim dhe ndryshim kartelash vetëm për <strong>kartelat tuaja të parapëlqyera</strong> <em>(Vetëm te rrjedha)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>U fshi</strong> një kartelë ose dosje",
    "A file or folder has been <strong>restored</strong>" : "<strong>U rikthye</strong> një kartelë ose dosje",
    "You created %1$s" : "Krijuat %1$s",
    "%2$s created %1$s" : "%2$s krijoi %1$s",
    "%1$s was created in a public folder" : "%1$s u krijua në një dosje publike",
    "You changed %1$s" : "Ndryshuat %1$s",
    "%2$s changed %1$s" : "%2$s ndryshoi %1$s",
    "You deleted %1$s" : "Fshitë %1$s",
    "%2$s deleted %1$s" : "%2$s fshiu %1$s",
    "You restored %1$s" : "Rikthyet %1$s",
    "%2$s restored %1$s" : "%2$s riktheu %1$s",
    "Changed by %2$s" : "Ndryshuar nga %2$s",
    "Deleted by %2$s" : "Fshirë nga %2$s",
    "Restored by %2$s" : "Rikthyer nga %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "S’keni leje të hyni të përdorni këtë kartelë/dosje - Ju lutemi, lidhuni me të zotin e saj që ta ndajë me ju.",
    "Upload (max. %s)" : "Ngarkim (max. %s)",
    "Settings" : "Rregullime",
    "Show hidden files" : "Shfaq kartela të fshehura",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Përdorni këtë adresë për <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">të hyrë te Kartelat tuaja përmes WebDAV-it</a>",
    "No files in here" : "S’ka kartela këtu",
    "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
    "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
    "Select all" : "Përzgjidhe krejt",
    "Upload too large" : "Ngarkim shumë i madh",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kartelat që po rrekeni të ngarkoni e tejkalojnë madhësinë maksimale për ngarkime kartelash në këtë shërbyes.",
    "No favorites" : "Pa të parapëlqyera",
    "Files and folders you mark as favorite will show up here" : "Këtu do të duken kartelat dhe dosjet që i shënoni si të parapëlqyera",
    "Text file" : "Kartelë tekst",
    "New text file.txt" : "Kartelë e re file.txt"
},
"nplurals=2; plural=(n != 1);");
